==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Boyutlar</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Genişlik:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Boşluk:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Ekranda Kalma Süresi</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Bazı birdirimler kendi ekranda kalma süresini ayarlar.</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Öntanımlı süre:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sn</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Ekrandaki konumu</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation type="unfinished">&lt;b&gt;Uyarı:&lt;/b&gt; Çalışan bir bildirim programı yok.
A fallback will be used.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Üçüncü parti bir bildirim proğramı (%1) çalışıyor.
Bu ayarlar onu etkilemeyecek!</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Bildirim deneme</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Bu bir test bildirimidir. Bundan sonra LXQT masaüstünüzde tüm bildirimler burada gösterilecek.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Masaüstü Bildirimleri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Gelişmiş Ayarlar</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Boyutlar</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Genişlik:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Boşluk:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Ekranda Kalma Süresi</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Bazı birdirimler kendi ekranda kalma süresini ayarlar.</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Öntanımlı süre:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sn</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Ekrandaki konumu</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="56"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Çalışan bir bildirim programı yok.
A fallback will be used.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Üçüncü parti bir bildirim proğramı (%1) çalışıyor.
Bu ayarlar onu etkilemeyecek!</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="112"/>
        <source>Notification demo </source>
        <translation>Bildirim deneme</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="113"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Bu bir test bildirimidir. Bundan sonra LXQT masaüstünüzde tüm bildirimler burada gösterilecek.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Masaüstü Bildirimleri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Basit Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Gelişmiş Ayarlar</translation>
    </message>
</context>
</TS>
